==> audio_io-0.0.1.tar.gz: lib/audio_io.dart <==
import 'dart:async';
import 'dart:ffi';
import 'dart:typed_data';
import 'package:flutter/services.dart';

class _Methods {
  static const start = 'start';
  static const stop = 'stop';
}

class _Strings {
  static const inputChannelName = 'com.wearemobilefirst.audio_io.inputAudio';
  static const outputChannelName = 'com.wearemobilefirst.audio_io.outputAudio';
  static const methodChannelName = 'com.wearemobilefirst.audio_io';
}

class AudioIo {
  static const MethodChannel _methods = const MethodChannel(_Strings.methodChannelName);
  static const EventChannel _input = const EventChannel(_Strings.inputChannelName);
  static const EventChannel _output = const EventChannel(_Strings.outputChannelName);
  static StreamSubscription<List<double>> _outputSubscription;
  static AudioIo instance = AudioIo();

  StreamController<List<double>> _outputController = StreamController<List<double>>.broadcast();

  Stream<List<double>> get input {
    var streamTransformer = StreamTransformer<dynamic, List<double>>.fromHandlers(
    handleData: (dynamic data, EventSink sink) {
      final listData = data as List;
      final converted = listData?.map((element){
        return element as double;
      })?.toList();
      sink.add(converted);
    }, 
    handleError: (Object error, StackTrace stacktrace, EventSink sink) {
      sink.addError('Something went wrong: $error');
    }, 
    handleDone: (EventSink sink) => sink.close(),
  );
    return _input.receiveBroadcastStream().transform(streamTransformer);
  }

  Sink<List<double>> get output {
    return _outputController.sink;
  }

  Future<void> start() async {
    _outputSubscription?.cancel();
    _outputSubscription = _outputController.stream.listen((output){
      //_output.binaryMessenger.send(_Strings.outputChannelName, output.buffer.asByteData());
      ByteBuffer buffer = Float64List.fromList(output).buffer;
      ByteData data = ByteData.view(buffer);
      _output.binaryMessenger.send(_Strings.outputChannelName, data);
    });
    await _methods.invokeMethod(_Methods.start);
  }

  Future<void> stop() async {
    await _methods.invokeMethod(_Methods.stop);
  }

  void dispose(){
    _outputController.sink.close();
    _outputController.close();
  }

}

==> audio_io-0.0.3.tar.gz: lib/audio_io.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class _Methods {
  static const start = 'start';
  static const stop = 'stop';
  static const outputFrame = 'outputFrame';
}

class _Strings {
  static const inputChannelName = 'com.wearemobilefirst.audio_io.inputAudio';
  static const outputChannelName = 'com.wearemobilefirst.audio_io.outputAudio';
  static const methodChannelName = 'com.wearemobilefirst.audio_io';
}

class AudioIo {
  static const MethodChannel _methods = const MethodChannel(_Strings.methodChannelName);
  static const EventChannel _input = const EventChannel(_Strings.inputChannelName);
  //static const EventChannel _output = const EventChannel(_Strings.outputChannelName);
  static StreamSubscription<List<double>> _outputSubscription;
  static AudioIo instance = AudioIo();

  StreamController<List<double>> _outputController = StreamController<List<double>>.broadcast();

  Stream<List<double>> get input {
    var streamTransformer = StreamTransformer<dynamic, List<double>>.fromHandlers(
    handleData: (dynamic data, EventSink sink) {
      final listData = data as List;
      final converted = listData?.map((element){
        return element as double;
      })?.toList();
      sink.add(converted);
    }, 
    handleError: (Object error, StackTrace stacktrace, EventSink sink) {
      sink.addError('Something went wrong: $error');
    }, 
    handleDone: (EventSink sink) => sink.close(),
  );
    return _input.receiveBroadcastStream().transform(streamTransformer);
  }

  Sink<List<double>> get output {
    return _outputController.sink;
  }

  Future<void> start() async {
    _outputSubscription?.cancel();
    _outputSubscription = _outputController.stream.listen((output){
      //_output.binaryMessenger.send(_Strings.outputChannelName, output.buffer.asByteData());
      //ByteBuffer buffer = Float64List.fromList(output).buffer;
      //ByteData data = ByteData.view(buffer);
      //_output.binaryMessenger.send(_Strings.outputChannelName, data);
      _methods.invokeMethod(_Methods.outputFrame, output);
    });
    await _methods.invokeMethod(_Methods.start);
  }

  Future<void> stop() async {
    await _methods.invokeMethod(_Methods.stop);
  }

  void dispose(){
    _outputController.sink.close();
    _outputController.close();
  }

}
